import six
from six.moves import range

__all__ = (
    "NucleotideTable",
    "NucleotideAlphabet",
    "NucleotideComplementTable",
    "nucleotide_reverse_complement",
)

def _build_compliment_table():
    _ctable = list(map(chr, range(0xff + 1)))
    for symbol in NucleotideAlphabet:
        complement = NucleotideTable[symbol]["complement"]
        _ctable[ord(symbol)] = complement
        _ctable[ord(symbol.lower())] = complement.lower()
    return str.join('', _ctable)

def _iupac_info(complement, matches):
    return {
        "complement": complement.upper(),
        "matches": tuple(matches.upper())
    }

NucleotideTable = {
    'A': _iupac_info('T', 'A'),
    'G': _iupac_info('C', 'G'),
    'C': _iupac_info('G', 'C'),
    'T': _iupac_info('A', 'T'),
    'U': _iupac_info('A', 'T'),
    'M': _iupac_info('K', 'AC'),
    'R': _iupac_info('Y', 'AG'),
    'Y': _iupac_info('R', 'CT'),
    'S': _iupac_info('S', 'CG'),
    'W': _iupac_info('W', 'AT'),
    'K': _iupac_info('M', 'GT'),
    'B': _iupac_info('V', 'CGT'),
    'D': _iupac_info('H', 'AGT'),
    'H': _iupac_info('D', 'ACT'),
    'V': _iupac_info('B', 'ACG'),
    'N': _iupac_info('N', 'AGCT')
}

NucleotideAlphabet = str.join('', tuple(NucleotideTable.keys()))
NucleotideComplimentTable = _build_compliment_table()

def nucleotide_reverse_complement(sequence):
    return sequence[::-1].translate(NucleotideComplimentTable)



#!/usr/bin/env python

from setuptools import setup, Extension

version = open('VERSION').read().strip()
download_url = "https://github.com/vishnubob/ssw/archive/v%s.tar.gz" % version
long_description = \
"""ssw is a fast implementation of the Smith-Waterman algorithm, which
uses the Single-Instruction Multiple-Data (SIMD) instructions to parallelize
the algorithm at the CPU level.  This repository wraps the SSW library into an
easy to install, high-level python interface with no external library dependancies.

The SSW library is written by Mengyao Zhao and Wan-Ping Lee, and this python
interface is maintained by Giles Hall.
"""

libssw_ext = {
    "sources": ["src/ssw/ssw.c"],
    "include_dirs": ["src/ssw"],
}

config = {
    "name": "ssw", 
    "version": version,
    "description": "Smith-Waterman Sequence Aligner",
    "author": "Giles Hall",
    "author_email": "giles@polymerase.org",
    "package_dir": {"ssw": "src"},
    "packages": ["ssw"],
    "classifiers": [
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: MIT License",
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
    ],
    "keywords": [
        "bioinformatics",
        "sequence alignment",
        "smith-waterman",
        "genomics",
        "proteomics"
    ],
    "install_requires": [
        "six",
    ],
    "platforms": "any",
    "ext_modules": [Extension("_libssw", **libssw_ext)],
    "zip_safe": False,
    "download_url": download_url,
    "url": "https://github.com/vishnubob/ssw",
    "long_description": long_description,
    "long_description_content_type": "text/x-rst",
}

if __name__ == "__main__":
    setup(**config)
